@@ -1,15 +1,20 @@
+from __future__ import absolute_import
+
 from greenhouse.compat import *
 from greenhouse.scheduler import *
-from greenhouse.utils import *
+from greenhouse.util import *
 from greenhouse.pool import *
+
 # scheduler.state.poller needs to be in place before the io import
-import greenhouse.poller
+from greenhouse import poller
+poller.set()
+
 from greenhouse.io import *
 from greenhouse.emulation import *
 from greenhouse.backdoor import *
 
 
-VERSION = (0, 6, 0, '')
+VERSION = (1, 0, 0, '')
 
 __version__ = ".".join(filter(None, (str(x) for x in VERSION)))
 
