@@ -1,5 +1,16 @@
 try:
-    from greenlet import greenlet, GreenletExit
+    from greenlet import greenlet
+    try:
+        from greenlet import GreenletExit
+    except ImportError, error:
+        try:
+            GreenletExit = greenlet.GreenletExit
+        except AttributeError:
+            raise error
+        else:
+            # pypy's greenlets don't allow weakrefs to them, this fixes that
+            class greenlet(greenlet):
+                pass
 except ImportError, error:
     try:
         from py.magic import greenlet
