@@ -3,12 +3,16 @@ from paver.path import path
 from paver.setuputils import setup
 
 
-VERSION = (0, 6, 0, "")
+VERSION = (1, 0, 0, "")
 
 setup(
     name="greenhouse",
     description="An I/O parallelism library making use of coroutines",
-    packages=["greenhouse", "greenhouse.io"],
+    packages=[
+        "greenhouse",
+        "greenhouse.io",
+        "greenhouse.emulation",
+        "greenhouse.ext"],
     version=".".join(filter(None, map(str, VERSION))),
     author="Travis Parker",
     author_email="travis.parker@gmail.com",
@@ -53,7 +57,9 @@ def clean():
 
 @task
 def docs():
-    sh("find docs -name *.rst | xargs touch")
+    # have to touch the automodules to build them every time since changes to
+    # the module's docstrings won't affect the timestamp of the .rst file
+    sh("find docs/source/greenhouse -name *.rst | xargs touch")
     sh("cd docs; make html")
 
 @task
